@@ -1,16 +1,16 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
-# This program is free software: you can redistribute it and/or modify it 
-# under the terms of the GNU General Public License version 3, as published 
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
-# 
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License along 
+#
+# You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
@@ -31,9 +31,7 @@ try:
     gi.require_version('AppIndicator3', '0.1')
     from gi.repository import AppIndicator3 # pylint: disable=E0611
     use_appindicator = True
-except ImportError:
-    use_appindicator = False
-except ValueError:
+except (ValueError, ImportError):
     use_appindicator = False
 
 from variety_lib import varietyconfig
@@ -285,9 +283,9 @@ class Indicator:
         try:
             from varietyslideshow import varietyslideshow
         except:
-            logger.warning('Variety Slideshow is not installed. '
-                           'Install it with "sudo apt-get install variety-slideshow", '
-                           'read more here: http://peterlevi.com/variety/slideshow/')
+            logger.warning('Variety Slideshow is not installed. This is an optional extension '
+                           'adding pan-and-zoom slideshows to Variety: see '
+                           'https://github.com/peterlevi/variety-slideshow for details')
         else:
             self.menu.append(Gtk.SeparatorMenuItem.new())
 
